@@ -19,6 +19,7 @@ from metapi.sampler import get_sample_id_
 from metapi.sampler import get_samples_id_by_assembly_group
 from metapi.sampler import get_samples_id_by_binning_group
 from metapi.sampler import get_assembly_group_by_binning_group
+from metapi.sampler import get_binning_group_by_assembly_group
 from metapi.sampler import get_multibinning_group_by_assembly_group
 
 from metapi.qcer import change
@@ -32,9 +33,13 @@ from metapi.assembler import parse_spades_params
 
 from metapi.aligner import flagstats_summary
 
+from metapi.predictor import parse_gff
+from metapi.predictor import extract_faa
+
 from metapi.binner import get_binning_info
 from metapi.binner import generate_bins
 from metapi.binner import extract_bins_report
+from metapi.binner import combine_jgi
 
 from metapi.checkmer import checkm_prepare
 from metapi.checkmer import checkm_reporter
