@@ -113,6 +113,10 @@ def get_assembly_group_by_binning_group(sample_df, binning_group):
     return sample_df.loc[:, :, binning_group, :].index.get_level_values("assembly_group").unique()
 
 
+def get_binning_group_by_assembly_group(sample_df, assembly_group):
+    return sample_df.loc[:, assembly_group, :, :].index.get_level_values("binning_group").unique()
+
+
 def get_multibinning_group_by_assembly_group(sample_df, assembly_group):
     return sample_df.loc[:, assembly_group, :, :].index.get_level_values("multibinning_group").unique()
 
@@ -127,3 +131,16 @@ def get_sample_id_(sample_df, wildcards, col):
 
 def get_bin_id(bin_df, wildcards, col):
     return bin_df.loc[wildcards.bin, [col]].dropna()[0]
+
+
+def sample_cluster_info(sample_df):
+    '''
+    vamb cluster
+    '''
+    binning_groups = sample_df.index.get_level_values("binning_group").unique()
+
+    for binning_group in binning_groups:
+        assembly_groups = sample_df.loc[:, :, binning_group].index.get_level_values("assembly_group").unique()
+        assembly_groups = sorted(assembly_groups)
+        for i in range(0, len(assembly_groups)):
+            print(f'''{assembly_groups[i]}\tS{i+1}''')
\ No newline at end of file
